@@ -40,6 +40,10 @@
  * 	  longer overallocate or underallocate
  * 8/7/11
  * 	- oop CMYK write was not inverting, thanks Ole
+ * 12/10/2011
+ * 	- write XMP data
+ * 18/10/2011
+ * 	- update Orientation as well
  */
 
 /*
@@ -312,10 +316,16 @@ write_tag( ExifData *ed, ExifTag tag, ExifFormat f, write_fn fn, void *data )
 		ExifEntry *entry;
 
 		entry = exif_entry_new();
+
+		/* tag must be set before calling exif_content_add_entry.
+		 */
+		entry->tag = tag; 
+
 		exif_content_add_entry( ed->ifd[0], entry );
 		exif_entry_initialize( entry, tag );
-		fn( entry, bo, data );
 		exif_entry_unref( entry );
+
+		fn( entry, bo, data );
 	}
 
 	return( 0 );
@@ -354,6 +364,62 @@ set_exif_resolution( ExifData *ed, IMAGE *im )
 
 	return( 0 );
 }
+
+static void *
+update_orientation_cb( VipsImage *in, const char *name, GValue *value, void *a )
+{
+	/* Sadly these strings are subject to i18n by libexif. We should
+	 * attach EXIF data as binary and leave interpretaion to the UI argh.
+	 */
+	static const char *orientations[] = {
+		"", 
+		"Top-left", "Top-right", "Bottom-right",
+		"Bottom-left", "Left-top", "Right-top",
+		"Right-bottom", "Left-bottom", 
+		NULL
+	};
+
+	ExifData *ed = (ExifData *) a;
+
+	int i;
+	ExifShort orientation;
+
+	if( vips_isprefix( "exif-Orientation", name ) ) {
+		const char *string;
+
+		if( !(string = vips_ref_string_get( value )) ) {
+			vips_warn( "im_jpeg2vips", 
+				"%s", _( "exif-Orientation is not a string" ) );
+			return( NULL );
+		}
+
+		orientation = 0;
+		for( i = 0; orientations[i]; i++ ) 
+			if( strlen( orientations[i] ) > 0 &&
+				vips_isprefix( orientations[i], string ) ) {
+				orientation = i;
+				break;
+			}
+		if( orientation == 0 ) {
+			vips_warn( "im_jpeg2vips", 
+				"%s", _( "unknown JPEG orientation" ) );
+			return( NULL );
+		}
+
+		if( write_tag( ed, EXIF_TAG_ORIENTATION, EXIF_FORMAT_SHORT,
+			write_short, &orientation ) ) {
+			vips_warn( "im_jpeg2vips", 
+				"%s", _( "error setting JPEG orientation" ) );
+			return( NULL );
+		}
+
+#ifdef DEBUG
+		printf( "im_vips2jpeg: updated orientation\n" );
+#endif /*DEBUG*/
+	}
+
+	return( NULL );
+}
 #endif /*HAVE_EXIF*/
 
 static int
@@ -376,9 +442,23 @@ write_exif( Write *write )
 		if( !(ed = exif_data_new_from_data( data, data_length )) )
 			return( -1 );
 	}
-	else 
+	else  {
 		ed = exif_data_new();
 
+		exif_data_set_option( ed, 
+			EXIF_DATA_OPTION_FOLLOW_SPECIFICATION );
+		exif_data_set_data_type( ed, EXIF_DATA_TYPE_COMPRESSED );
+		exif_data_set_byte_order( ed, EXIF_BYTE_ORDER_INTEL );
+	
+		/* Create the mandatory EXIF fields with default data.
+		 */
+		exif_data_fix( ed );
+	}
+
+	/* Update EXIF orientation from VIPS.
+	 */
+	(void) vips_image_map( write->in, update_orientation_cb, ed );
+
 	/* Update EXIF resolution from VIPS.
 	 */
 	if( set_exif_resolution( ed, write->in ) ) {
@@ -413,7 +493,7 @@ write_exif( Write *write )
 			return( -1 );
 
 #ifdef DEBUG
-		printf( "im_vips2jpeg: attaching %d bytes of EXIF\n", 
+		printf( "im_vips2jpeg: attaching %zd bytes of EXIF\n", 
 			data_length  );
 #endif /*DEBUG*/
 
@@ -425,6 +505,31 @@ write_exif( Write *write )
 	return( 0 );
 }
 
+static int
+write_xmp( Write *write )
+{
+	unsigned char *data;
+	size_t data_length;
+
+	/* No libexif ... just copy the embedded EXIF over.
+	 */
+	if( im_header_get_typeof( write->in, VIPS_META_XMP_NAME ) ) {
+		if( im_meta_get_blob( write->in, VIPS_META_XMP_NAME, 
+			(void *) &data, &data_length ) )
+			return( -1 );
+
+#ifdef DEBUG
+		printf( "im_vips2jpeg: attaching %zd bytes of XMP\n", 
+			data_length  );
+#endif /*DEBUG*/
+
+		jpeg_write_marker( &write->cinfo, JPEG_APP0 + 1, 
+			data, data_length );
+	}
+
+	return( 0 );
+}
+
 /* ICC writer from lcms, slight tweaks.
  */
 
@@ -629,6 +734,9 @@ write_vips( Write *write, int qfac, const char *profile )
 	if( write_exif( write ) )
 		return( -1 );
 
+	if( write_xmp( write ) )
+		return( -1 );
+
 	/* A profile supplied as an argument overrides an embedded profile.
 	 * "none" means don't attach a profile.
 	 */
