@@ -62,12 +62,6 @@ typedef struct {
 			 *(channel select)	*/
 } IMAGE_BOX;
 
-/* Compatibility typedefs.
- */
-typedef VipsDemandStyle im_demand_type;
-typedef VipsProgress im_time_t;
-typedef VipsImage IMAGE;
-
 int im_extract( IMAGE *, IMAGE *, IMAGE_BOX * );
 DOUBLEMASK *im_measure( IMAGE *im, IMAGE_BOX *box, int h, int v, 
 	int *sel, int nsel, const char *name );
@@ -136,6 +130,19 @@ void im_diagnostics( const char *fmt, ... )
 void im_warning( const char *fmt, ... )
 	__attribute__((format(printf, 1, 2)));
 
+int im_iterate( VipsImage *im,
+	VipsStartFn start, VipsGenerateFn generate, VipsStopFn stop,
+	void *a, void *b
+);
+
+/* Async rendering.
+ */
+int im_render_priority( VipsImage *in, VipsImage *out, VipsImage *mask,
+	int width, int height, int max,
+	int priority,
+	void (*notify)( VipsImage *, VipsRect *, void * ), void *client );
+int im_cache( VipsImage *in, VipsImage *out, int width, int height, int max );
+
 /* Deprecated operations.
  */
 int im_cmulnorm( IMAGE *in1, IMAGE *in2, IMAGE *out );
@@ -146,10 +153,30 @@ int im_render_fade( IMAGE *in, IMAGE *out, IMAGE *mask,
 	int width, int height, int max,
 	int fps, int steps,
 	int priority,
-	void (*notify)( IMAGE *, Rect *, void * ), void *client );
+	void (*notify)( IMAGE *, VipsRect *, void * ), void *client );
 int im_render( IMAGE *in, IMAGE *out, IMAGE *mask,
 	int width, int height, int max,
-	void (*notify)( IMAGE *, Rect *, void * ), void *client );
+	void (*notify)( IMAGE *, VipsRect *, void * ), void *client );
+
+int im_cooc_matrix( IMAGE *im, IMAGE *m,
+	int xp, int yp, int xs, int ys, int dx, int dy, int flag );
+int im_cooc_asm( IMAGE *m, double *asmoment );
+int im_cooc_contrast( IMAGE *m, double *contrast );
+int im_cooc_correlation( IMAGE *m, double *correlation );
+int im_cooc_entropy( IMAGE *m, double *entropy );
+
+int im_glds_matrix( IMAGE *im, IMAGE *m,
+	int xpos, int ypos, int xsize, int ysize, int dx, int dy );
+int im_glds_asm( IMAGE *m, double *asmoment );
+int im_glds_contrast( IMAGE *m, double *contrast );
+int im_glds_entropy( IMAGE *m, double *entropy );
+int im_glds_mean( IMAGE *m, double *mean );
+
+int im_dif_std();
+int im_simcontr( IMAGE *out, int xsize, int ysize );
+int im_spatres( IMAGE *in,  IMAGE *out, int step );
+
+int im_stretch3( IMAGE *in, IMAGE *out, double dx, double dy );
 
 /* Renamed operations.
  */
@@ -231,7 +258,7 @@ int im_rank_raw( IMAGE *in, IMAGE *out, int xsize, int ysize, int order );
 int im_circle( IMAGE *im, int cx, int cy, int radius, int intensity );
 int im_line( IMAGE *, int, int, int, int, int );
 int im_segment( IMAGE *test, IMAGE *mask, int *segments );
-int im_paintrect( IMAGE *im, Rect *r, PEL *ink );
+int im_paintrect( IMAGE *im, VipsRect *r, PEL *ink );
 int im_insertplace( IMAGE *main, IMAGE *sub, int x, int y );
 
 int im_flood_copy( IMAGE *in, IMAGE *out, int x, int y, PEL *ink );
@@ -239,22 +266,22 @@ int im_flood_blob_copy( IMAGE *in, IMAGE *out, int x, int y, PEL *ink );
 int im_flood_other_copy( IMAGE *test, IMAGE *mark, IMAGE *out, 
 	int x, int y, int serial );
 
-int im_flood( IMAGE *im, int x, int y, PEL *ink, Rect *dout );
-int im_flood_blob( IMAGE *im, int x, int y, PEL *ink, Rect *dout );
+int im_flood( IMAGE *im, int x, int y, PEL *ink, VipsRect *dout );
+int im_flood_blob( IMAGE *im, int x, int y, PEL *ink, VipsRect *dout );
 int im_flood_other( IMAGE *test, IMAGE *mark, 
-	int x, int y, int serial, Rect *dout );
+	int x, int y, int serial, VipsRect *dout );
 
 int im_fastline( IMAGE *im, int x1, int y1, int x2, int y2, PEL *pel );
 int im_fastlineuser( IMAGE *im, 
 	int x1, int y1, int x2, int y2, 
 	int (*fn)(), void *client1, void *client2, void *client3 );
 
-int im_plotmask( IMAGE *im, int ix, int iy, PEL *ink, PEL *mask, Rect *r );
+int im_plotmask( IMAGE *im, int ix, int iy, PEL *ink, PEL *mask, VipsRect *r );
 int im_readpoint( IMAGE *im, int x, int y, PEL *pel );
 int im_plotpoint( IMAGE *im, int x, int y, PEL *pel );
 
-int im_smudge( IMAGE *image, int ix, int iy, Rect *r );
-int im_smear( IMAGE *im, int ix, int iy, Rect *r );
+int im_smudge( IMAGE *image, int ix, int iy, VipsRect *r );
+int im_smear( IMAGE *im, int ix, int iy, VipsRect *r );
 
 #ifdef __cplusplus
 }
