@@ -112,7 +112,7 @@
  * Various convenience functions (eg. vips_image_set_int()) let you easily 
  * attach 
  * simple types like
- * numbers, strings and memory blocks to images. Use vips_header_map() to loop
+ * numbers, strings and memory blocks to images. Use vips_image_map() to loop
  * over an image's fields, including all metadata.
  *
  * Items of metadata are identified by strings. Some strings are reserved, for
@@ -189,8 +189,12 @@ static HeaderField old_double_field[] = {
 
 /* This is used by (eg.) VIPS_IMAGE_SIZEOF_ELEMENT() to calculate object
  * size.
+ *
+ * We can't use size_t or off_t because we have to work on some platforms
+ * which have these as 32-bit and we need to calculate addresses in large
+ * files. 
  */
-const size_t vips__image_sizeof_bandformat[] = {
+const guint64 vips__image_sizeof_bandformat[] = {
 	sizeof( unsigned char ), 	/* VIPS_FORMAT_UCHAR */
 	sizeof( signed char ), 		/* VIPS_FORMAT_CHAR */
 	sizeof( unsigned short ), 	/* VIPS_FORMAT_USHORT */
@@ -479,8 +483,6 @@ vips_image_init_fields( VipsImage *image,
 static void *
 meta_cp_field( VipsMeta *meta, VipsImage *dst )
 {
-	VipsMeta *meta_copy;
-
 #ifdef DEBUG
 {
 	char *str_value;
@@ -494,7 +496,7 @@ meta_cp_field( VipsMeta *meta, VipsImage *dst )
 
 	/* No way to return error here, sadly.
 	 */
-	meta_copy = meta_new( dst, meta->field, &meta->value );
+	(void) meta_new( dst, meta->field, &meta->value );
 
 #ifdef DEBUG
 	meta_sanity( dst );
