@@ -218,6 +218,8 @@ vips_operation_new( const char *name )
 	GType type;
 	VipsOperation *operation;
 
+	vips_check_init();
+
 	if( !(type = vips_type_find( "VipsOperation", name )) )
 		return( NULL );
 	operation = VIPS_OPERATION( g_object_new( type, NULL ) );
@@ -281,7 +283,7 @@ vips_operation_set_valist_required( VipsOperation *operation, va_list ap )
 		else if( (argument_class->flags & VIPS_ARGUMENT_REQUIRED) &&
 			(argument_class->flags & VIPS_ARGUMENT_OUTPUT) &&
 			!argument_instance->assigned ) {
-			void *arg;
+			void *arg __attribute((unused));
 
 			/* Output args are all pointers to places to write 
 			 * results. Skip here, we use these during the output 
@@ -299,6 +301,7 @@ vips_operation_set_valist_required( VipsOperation *operation, va_list ap )
 	return( 0 );
 }
 
+/* See comments on calls below.
 static int
 vips_operation_set_valist_optional( VipsOperation *operation, va_list ap )
 {
@@ -309,6 +312,7 @@ vips_operation_set_valist_optional( VipsOperation *operation, va_list ap )
 
 	return( 0 );
 }
+ */
 
 static void
 vips_operation_get_valist( VipsOperation *operation, va_list ap )
@@ -383,11 +387,19 @@ vips_call( const char *operation_name, ... )
 	vips_object_print( VIPS_OBJECT( operation ) );
 #endif /*VIPS_DEBUG*/
 
+	/* This code is broken. Fixed correctly in the next version, but for
+	 * here just ignore optional arguments.
 	va_start( ap, operation_name );
 	result = vips_operation_set_valist_required( operation, ap )  ||
 		vips_operation_set_valist_optional( operation, ap ) ||
 		vips_object_build( VIPS_OBJECT( operation ) );
 	va_end( ap );
+	 */
+
+	va_start( ap, operation_name );
+	result = vips_operation_set_valist_required( operation, ap )  ||
+		vips_object_build( VIPS_OBJECT( operation ) );
+	va_end( ap );
 
 	/* Build failed: junk args and back out.
 	 */
@@ -430,11 +442,19 @@ vips_call_split( const char *operation_name, va_list optional, ... )
 	vips_object_print( VIPS_OBJECT( operation ) );
 #endif /*VIPS_DEBUG*/
 
+	/* This code is broken. Fixed correctly in the next version, but for
+	 * here just ignore optional arguments.
 	va_start( required, optional );
 	result = vips_operation_set_valist_required( operation, required ) ||
 		vips_operation_set_valist_optional( operation, optional ) ||
 		vips_object_build( VIPS_OBJECT( operation ) );
 	va_end( required );
+	 */
+
+	va_start( required, optional );
+	result = vips_operation_set_valist_required( operation, required ) ||
+		vips_object_build( VIPS_OBJECT( operation ) );
+	va_end( required );
 
 	/* Build failed: junk args and back out.
 	 */
